@@ -201,7 +201,10 @@ class GoogleSearchConsole:
 
         Returns as pd.Series of Bool if the query is branded
         """
-        branded_list = self._branded_dict[self._current_site]
+        try:
+            branded_list = self._branded_dict[self._current_site]
+        except KeyError:
+            return False
         if branded_list in [nan,[],['']]:
             return False
         return pd.Series(query_list).str.contains(
